@@ -22,7 +22,7 @@ def module_main():
         for file in args.files:
             trasker.register_file(file)
 
-    if(args.directory != None):
+    elif(args.directory != None):
         recursive = not args.nonrecursive
         trasker.register_directory(args.directory, recursive=recursive)
 
